import { defineStore } from 'pinia';
import { ref, computed } from 'vue';

export const useAuthStore = defineStore('auth', () => {
    const accessToken = ref(localStorage.getItem('accessToken') || ''); // 从 localStorage 获取 token
    const user = ref(null);

    const isAuthenticated = computed(() => !!accessToken.value); // 判断用户是否已认证

    function saveTokens(access: string) {
        accessToken.value = access;
        localStorage.setItem('accessToken', access); // 保存到 localStorage
    }

    function saveUser(userInfo: any) {
        user.value = userInfo; // 更新响应式用户信息
        sessionStorage.setItem('user', JSON.stringify(userInfo)); // 存储原始用户信息到 sessionStorage
    }

    function logout() {
        accessToken.value = '';
        user.value = null;
        localStorage.removeItem('accessToken'); // 从 localStorage 删除 token
        sessionStorage.removeItem('user');
    }

    return { accessToken, user, isAuthenticated, saveTokens, saveUser, logout };
});